pub(crate) struct Globals {
extra: OsExtraData,
registry: Registry<OsStorage>,
}Fields
extra: OsExtraDataregistry: Registry<OsStorage>Implementations
Sourceimpl Globals
impl Globals
Sourcepub(crate) fn register_listener(&self, event_id: usize) -> Receiver<()>
pub(crate) fn register_listener(&self, event_id: usize) -> Receiver<()>
Registers a new listener for event_id.
Sourcepub(crate) fn record_event(&self, event_id: usize)
pub(crate) fn record_event(&self, event_id: usize)
Marks event_id as having been delivered, without broadcasting it to
any listeners.
Sourcepub(crate) fn broadcast(&self) -> bool
pub(crate) fn broadcast(&self) -> bool
Broadcasts all previously recorded events to their respective listeners.
Returns true if an event was delivered to at least one listener.
pub(crate) fn storage(&self) -> &OsStorage