Registry

Struct Registry 

pub(crate) struct Registry<S> {
    storage: S,
}
Manages and distributes event notifications to any registered listeners.

Generic over the underlying storage to allow for domain specific optimizations (e.g. eventIds may or may not be contiguous).

Fields

storage: S

Implementations

Source

impl<S> Registry<S>

fn new(storage: S) -> Self

Source

impl<S: Storage> Registry<S>

fn register_listener(&self, event_id: usize) -> Receiver<()>

Registers a new listener for event_id.

fn record_event(&self, event_id: usize)

Marks event_id as having been delivered, without broadcasting it to any listeners.

fn broadcast(&self) -> bool

Broadcasts all previously recorded events to their respective listeners.

Returns true if an event was delivered to at least one listener.