pub(crate) struct Registry<S> {
storage: S,
}Expand description
Manages and distributes event notifications to any registered listeners.
Generic over the underlying storage to allow for domain specific
optimizations (e.g. eventIds may or may not be contiguous).
Fields
storage: SImplementations